.. _jadoc:

deep_translatorのドキュメントへようこそ！
======================================

違う言語でドキュメントを読みたい場合は :doc:`こちら<../other_lang>`.

.. toctree::
   :maxdepth: 2 
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

目次
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
